SystemOrganization addCategory: #'Orange-Resource'!

ALComponentResource subclass: #ORAuthBasicResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orange-Resource'!

!ORAuthBasicResource commentStamp: 'chc 6/22/2015 14:50' prior: 0!
Used by ORAuthApplication. Drops down browser window for username and password.!

!ORAuthBasicResource methodsFor: 'as yet unclassified' stamp: 'chc 6/23/2015 16:39'!
authorized: result locator: aLocator
	| root cookie url |
	root := component rematerialize.
	url := aLocator urlForResource: root asResource.
	cookie := ALCookie name: 'auth' value: result token.
	cookie path: '/'.
	^ (ALResponse seeOther: url)
			setCookie: cookie; 
			yourself! !

!ORAuthBasicResource methodsFor: 'as yet unclassified' stamp: 'chc 2/3/2015 16:08'!
denied
	^ ALResponse status: 401 reason: 'Authentication failed'! !

!ORAuthBasicResource methodsFor: 'as yet unclassified' stamp: 'chc 2/10/2015 15:46'!
handleGet: aRequest locator: aLocator
	| request result authstring |
	(aRequest authorization isNil)
		ifTrue: [^self respondWithChallenge]
		ifFalse: [
	authstring := (aRequest authorization copyAfter: Character space) base64Decoded.
	request := ALAuthenticationRequest withUsername:  (authstring copyUpTo: $:)   password: (authstring copyAfter: $:).
	result := request signal].
	^(result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [ self denied ]
			! !

!ORAuthBasicResource methodsFor: 'as yet unclassified' stamp: 'chc 2/3/2015 16:15'!
respondWithChallenge
	^ALResponse unauthorized
		wwwAuthenticate: 'Basic Realm = "My Server"';
			yourself! !

ALComponentResource subclass: #ORAuthFormResource
	instanceVariableNames: 'resource form'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orange-Resource'!

!ORAuthFormResource commentStamp: 'chc 6/22/2015 14:50' prior: 0!
Catches a username and password sent by a page like ORForm. !

!ORAuthFormResource class methodsFor: 'as yet unclassified' stamp: 'chc 4/13/2015 14:50'!
resource: aResource form: aForm
	^ self basicNew
		initializeWithResource: aResource form: aForm ! !

!ORAuthFormResource methodsFor: 'private' stamp: 'chc 4/13/2015 14:50'!
applyRequest: aRequest
	| data |
	data := aRequest readEntityWith: [ :in | ALFormDataParser parse: (in encoding: #ascii) ].
	form appyData: data.
	^ form process ifNil: [ resource ]! !

!ORAuthFormResource methodsFor: 'public' stamp: 'chc 7/6/2015 11:19'!
authorized: result locator: aLocator
	| root url |
	root := resource component rematerialize.
	root current: ALCounterExample new.
	url := aLocator urlForResource: root asResource.
	^ALResponse seeOther: url
			! !

!ORAuthFormResource methodsFor: 'public' stamp: 'chc 6/17/2015 15:13'!
denied
	^ ALResponse status: 401 reason: 'Authentication failed'! !

!ORAuthFormResource methodsFor: 'private' stamp: 'chc 4/13/2015 14:50'!
handleData: data locator: aLocator
	| result url |
	form appyData: data.
	result := form process ifNil: [ resource ].
	url := aLocator urlForResource: result.
	^ ALResponse seeOther: url! !

!ORAuthFormResource methodsFor: 'public' stamp: 'chc 6/23/2015 16:18'!
handleGet: aRequest locator: aLocator
	| data request result |
	data := aRequest url query.
	request := ALAuthenticationRequest withUsername: (data at: 1) value password: (data at: 2) value.
	result := request signal.
	^(result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [ self denied ]! !

!ORAuthFormResource methodsFor: 'public' stamp: 'chc 4/13/2015 14:50'!
handlePost: aRequest locator: aLocator
	| data |
	data := aRequest readEntityWith: [ :in | ALFormDataParser parse: (in encoding: #ascii) ].
	^ self handleData: data locator: aLocator! !

!ORAuthFormResource methodsFor: 'initialization' stamp: 'chc 4/13/2015 14:50'!
initializeWithResource: aResource form: aForm
	self initialize.
	resource := aResource.
	form := aForm.! !

ALComponentResource subclass: #ORAuthJSONResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orange-Resource'!

!ORAuthJSONResource commentStamp: 'chc 6/22/2015 14:51' prior: 0!
Catches a username and password sent as JSON by a compoment like ORAngularJS. !

!ORAuthJSONResource methodsFor: 'as yet unclassified' stamp: 'chc 7/6/2015 11:55'!
authorized: result locator: aLocator
	| root cookie url |
	root := component rematerialize.
	"[root noteDispatch]
		on: ALUserStipulation
		do: [:stipulation | stipulation component auth: true ]."
	url := aLocator urlForResource: root asResource.
	cookie := ALCookie name: 'auth' value: result token.
	cookie path: '/'.
	^ (ALResponse seeOther: url)
		setCookie: cookie;
		"date: DateAndTime now;
		keepAlive: 'timeout=10, max=20';"
		yourself! !

!ORAuthJSONResource methodsFor: 'as yet unclassified' stamp: 'chc 3/11/2015 14:17'!
denied
	^ ALResponse status: 401 reason: 'Authentication failed'! !

!ORAuthJSONResource methodsFor: 'as yet unclassified' stamp: 'chc 7/6/2015 11:56'!
handleGet: aRequest locator: aLocator
	| request result authstring |
self halt.
	(aRequest authorization isNil)
		ifTrue: [^self respondWithChallenge]
		ifFalse: [
	authstring := (aRequest authorization copyAfter: Character space) base64Decoded.
	request := ALAuthenticationRequest withUsername:  (authstring copyUpTo: $:)   password: (authstring copyAfter: $:).
	result := request signal].
	^(result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [ self denied ]
			! !

!ORAuthJSONResource methodsFor: 'as yet unclassified' stamp: 'chc 7/6/2015 11:55'!
handlePost: aRequest locator: aLocator
	| request result |
self halt.
	request := ALAuthenticationRequest new.
	aRequest readEntityWith: 
		[:in | ALJsonParser  parse: in for: request].
	result := request signal.
	^ (result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [self denied]! !

ALResource subclass: #ORUploadResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orange-Resource'!

!ORUploadResource commentStamp: 'chc 6/19/2015 13:30' prior: 0!
#handlePut:locator: is getting data from a request and feeding it to a form parser ALFormDataParser


A snippet or related (?) code: 

aRequest readEntityWith: [ :in |  stream := (FSLocator imageDirectory / 'package-cache' / 'fooforall.txt') writeStream.
									stream nextPutAll: in.					
								      stream close. ].


Snippets of code from MCWebClient: 

isValidMczName: string
	^ string isString 
		and: [ string isEmpty not
			and: [ (string endsWith: '.mcz')
				and: [ (string includes: $/) not ] ] ]

	| name |
	name := request url allButFirst.
	((self isValidMczName: name) and: [ (self directory fileExists: name) not ]) 
		ifTrue: [
			self directory newFileNamed: name do: [ :file | | response |
				file binary.
				request streamFrom: request stream to: file size: request contentLength progress: nil.
				request sendCreated ] ]
		ifFalse: [ request sendBadRequest ]

	repositoryListing
	^ String streamContents: [ :str |
		str nextPutAll: '<html><head><title>'; nextPutAll: self realm; nextPutAll: '</title></head>'.
		str nextPutAll: '<body><h1>'; nextPutAll: self realm; nextPutAll: '</h1>'.
		str nextPutAll: '<ul>'.
		self mczEntries do: [ :each | 
			str nextPutAll: '<li><a href=""'; nextPutAll: each; nextPutAll: '"">'; nextPutAll: each; nextPutAll: '</a></li>'].
		str nextPutAll: '</ul></body></html>' ]!

!ORUploadResource methodsFor: 'public' stamp: 'chc 5/19/2015 14:07'!
handleGet: aRequest locator: aLocator
	| data request result |
	data := aRequest url query.
	request := ALAuthenticationRequest withUsername: (data at: 1) value password: (data at: 2) value.
	result := request signal.
	^(result notNil and: [result isSuccess])
		ifTrue: [self authorized: result locator: aLocator]
		ifFalse: [ self denied ]! !

!ORUploadResource methodsFor: 'public' stamp: 'chc 5/19/2015 14:07'!
handlePost: aRequest locator: aLocator
	| data |
	data := aRequest readEntityWith: [ :in | ALFormDataParser parse: (in encoding: #ascii) ].
	^ self handleData: data locator: aLocator! !
